package jalview.datamodel.features;

import jalview.datamodel.SequenceFeature;
import jalview.util.matcher.MatcherI;

/**
 * An interface for an object that can apply a match condition to a
 * SequenceFeature object
 * 
 * @author gmcarstairs
 */
public interface FeatureMatcherI
{
  /**
   * Answers true if the value provided for this matcher's key passes this
   * matcher's match condition
   * 
   * @param feature
   * @return
   */
  boolean matches(SequenceFeature feature);

  /**
   * Answers the value key this matcher operates on
   * 
   * @return
   */
  String[] getKey();

  /**
   * Answers the match condition that is applied
   * 
   * @return
   */
  MatcherI getMatcher();
}
